@@ -38,6 +38,7 @@ class RingCapability(Enum):
     OPEN = auto()
     KNOCK = auto()
     PRE_ROLL = auto()
+    DING = auto()
 
     @staticmethod
     def from_name(name: str) -> RingCapability:
@@ -65,6 +66,7 @@ DEFAULT_VIDEO_DOWNLOAD_TIMEOUT = 120
 # API endpoints
 API_VERSION = "11"
 API_URI = "https://api.ring.com"
+APP_API_URI = "https://prd-api-us.prd.rings.solutions"
 USER_AGENT = "android:com.ringapp"
 
 # random uuid, used to make a hardware id that doesn't change or clash
@@ -72,7 +74,10 @@ NAMESPACE_UUID = "379378b0-f747-4b67-a10f-3b13327e8879"
 
 DEFAULT_LISTEN_EVENT_EXPIRES_IN = 180
 # for Ring android app.  703521446232 for ring-site
-RING_SENDER_ID = 876313859327
+FCM_RING_SENDER_ID = "876313859327"
+FCM_API_KEY = "AIzaSyCv-hdFBmmdBBJadNy-TFwB-xN_H5m3Bk8"
+FCM_PROJECT_ID = "ring-17770"
+FCM_APP_ID = "1:876313859327:android:e10ec6ddb3c81f39"
 
 CLI_TOKEN_FILE = "ring_token.cache"  # noqa: S105
 GCM_TOKEN_FILE = "ring_gcm_token.cache"  # noqa: S105
@@ -109,15 +114,24 @@ INTERCOM_INVITATIONS_ENDPOINT = LOCATIONS_ENDPOINT + "/invitations"
 INTERCOM_INVITATIONS_DELETE_ENDPOINT = LOCATIONS_ENDPOINT + "/invitations/{1}"
 INTERCOM_ALLOWED_USERS = LOCATIONS_ENDPOINT + "/users"
 
+# New API endpoints for web rtc streaming
+RTC_STREAMING_TICKET_ENDPOINT = "/api/v1/clap/ticket/request/signalsocket"
+RTC_STREAMING_WEB_SOCKET_ENDPOINT = "wss://api.prod.signalling.ring.devices.a2z.com:443/ws?api_version=4.0&auth_type=ring_solutions&client_id=ring_site-{0}&token={1}"
+
 KIND_DING = "ding"
 KIND_MOTION = "motion"
 KIND_INTERCOM_UNLOCK = "intercom_unlock"
+KIND_ALARM_MODE_NONE = "alarm_mode_none"
+KIND_ALARM_MODE_SOME = "alarm_mode_some"
+KIND_ALARM_SIREN = "alarm_siren"
+KIND_ALARM_SILENCED = "alarm_silenced"
+
 # chime test sound kinds
 CHIME_TEST_SOUND_KINDS = (KIND_DING, KIND_MOTION)
 
 # default values
 CHIME_VOL_MIN = 0
-CHIME_VOL_MAX = 10
+CHIME_VOL_MAX = 11
 
 DOORBELL_VOL_MIN = 0
 DOORBELL_VOL_MAX = 11
@@ -136,6 +150,9 @@ DOORBELL_EXISTING_TYPE = {0: "Mechanical", 1: "Digital", 2: "Not Present"}
 SIREN_DURATION_MIN = 0
 SIREN_DURATION_MAX = 120
 
+DOORBELL_EXISTING_DURATION_MIN = 0
+DOORBELL_EXISTING_DURATION_MAX = 10
+
 # device model kinds
 CHIME_KINDS = ["chime", "chime_v2"]
 CHIME_PRO_KINDS = ["chime_pro", "chime_pro_v2"]
@@ -183,6 +200,25 @@ PUSH_ACTION_DING = "com.ring.push.HANDLE_NEW_DING"
 PUSH_ACTION_MOTION = "com.ring.push.HANDLE_NEW_motion"
 PUSH_ACTION_INTERCOM_UNLOCK = "com.ring.push.INTERCOM_UNLOCK_FROM_APP"
 
+PUSH_NOTIFICATION_DING = "com.ring.pn.live-event.ding"
+PUSH_NOTIFICATION_MOTION = "com.ring.pn.live-event.motion"
+PUSH_NOTIFICATION_INTERCOM = "com.ring.pn.live-event.intercom"
+PUSH_NOTIFICATION_INTERCOM_UNLOCK = "com.ring.pn.intercom.virtual.unlock"
+
+PUSH_NOTIFICATION_KINDS = {
+    PUSH_ACTION_DING: KIND_DING,  # legacy
+    PUSH_NOTIFICATION_DING: KIND_DING,
+    PUSH_ACTION_MOTION: KIND_MOTION,  # legacy
+    PUSH_NOTIFICATION_MOTION: KIND_MOTION,
+    PUSH_NOTIFICATION_INTERCOM: KIND_DING,
+    PUSH_ACTION_INTERCOM_UNLOCK: KIND_INTERCOM_UNLOCK,
+    PUSH_NOTIFICATION_INTERCOM_UNLOCK: KIND_INTERCOM_UNLOCK,
+    "com.ring.push.HANDLE_NEW_SECURITY_PANEL_MODE_NONE_NOTICE": KIND_ALARM_MODE_NONE,
+    "com.ring.push.HANDLE_NEW_SECURITY_PANEL_MODE_SOME_NOTICE": KIND_ALARM_MODE_SOME,
+    "com.ring.push.HANDLE_NEW_USER_SOUND_SIREN": KIND_ALARM_SIREN,
+    "com.ring.push.HANDLE_NEW_NON_ALARM_SIREN_SILENCED": KIND_ALARM_SILENCED,
+}
+
 POST_DATA_JSON = {
     "api_version": API_VERSION,
     "device_model": "ring-doorbell",
@@ -215,3 +251,14 @@ PERSIST_TOKEN_DATA = {
     "device[metadata][architecture]": "x86",
     "device[metadata][language]": "en",
 }
+
+ICE_SERVERS = [
+    "stun:stun.kinesisvideo.us-east-1.amazonaws.com:443",
+    "stun:stun.kinesisvideo.us-east-2.amazonaws.com:443",
+    "stun:stun.kinesisvideo.us-west-2.amazonaws.com:443",
+    "stun:stun.l.google.com:19302",
+    "stun:stun1.l.google.com:19302",
+    "stun:stun2.l.google.com:19302",
+    "stun:stun3.l.google.com:19302",
+    "stun:stun4.l.google.com:19302",
+]
